Receiver

Struct Receiver 

pub struct Receiver<T> { /* private fields */ }
The Receiver handle of a SPSC channel. Created by create function.

Implementations

Source

impl<T> Receiver<T>

pub fn recv(&mut self) -> Result<T, RecvErr>

Tries to receive a message. If no message is available, Err(RecvErr::NoMessage) is returned. If the sender disconnected, Err(RecvErr::NoSender) is returned.

pub fn is_connected(&self) -> bool

Tests if the Sender is still connected. There are no guarantees that recv will succeed if this method returns true because the Receiver may disconnect meanwhile. This method may also return true if the Sender disconnected but there are messages pending in the buffer.