Sender

Struct Sender 

pub struct Sender<T> { /* private fields */ }
The Sender handle of a SPSC channel. Created by create function.

Implementations

Source

impl<T> Sender<T>

pub fn send(&mut self, message: T) -> Result<(), NoRecv<T>>

Sends a message and if the receiver disconnected, an error is returned.

pub fn is_connected(&self) -> bool

Tests if the Receiver is still connected. There are no guarantees that send will succeed if this method returns true because the Receiver may disconnect meanwhile.